pub enum StateParameter {
Show 18 variants
Element(OrbitalElement),
BdotR(),
BdotT(),
BLTOF(),
Cd(),
Cr(),
DryMass(),
Epoch(),
GuidanceMode(),
Isp(),
PropMass(),
ThrustX(),
ThrustY(),
ThrustZ(),
ThrustInPlane(LocalFrame),
ThrustOutOfPlane(LocalFrame),
Thrust(),
TotalMass(),
}Variants
Element(OrbitalElement)
BdotR()
B-Plane B⋅R
BdotT()
B-Plane B⋅T
BLTOF()
B-Plane LTOF
Cd()
Coefficient of drag
Cr()
Coefficient of reflectivity
DryMass()
Dry mass (kg)
Epoch()
The epoch of the state
GuidanceMode()
Return the guidance mode of the spacecraft
Isp()
Specific impulse (isp) in seconds
PropMass()
prop mass in kilograms
ThrustX()
Inertial thrust-direction x component
ThrustY()
Inertial thrust-direction y component
ThrustZ()
Inertial thrust-direction z component
ThrustInPlane(LocalFrame)
In-plane thrust angle in degrees for the requested local frame
ThrustOutOfPlane(LocalFrame)
Out-of-plane thrust angle in degrees for the requested local frame
Thrust()
Thrust (Newtons)
TotalMass()
Total mass
Implementations
Sourceimpl StateParameter
impl StateParameter
Sourcepub fn default_event_precision(&self) -> f64
pub fn default_event_precision(&self) -> f64
Returns the default event finding precision in the unit of that parameter
Sourcepub const fn is_b_plane(&self) -> bool
pub const fn is_b_plane(&self) -> bool
Returns whether this parameter is of the B-Plane kind
Sourcepub const fn is_orbital(&self) -> bool
pub const fn is_orbital(&self) -> bool
Returns whether this is an orbital parameter
Sourcepub const fn is_for_spacecraft(&self) -> bool
pub const fn is_for_spacecraft(&self) -> bool
Returns whether this parameter is only applicable to a spacecraft state
pub const fn unit(&self) -> &'static str